@@ -9,6 +9,7 @@
 #'@return p-values
 #'@keywords internal
 effectpowermc = function(fit, type="III", test = "Pr(>Chisq)", ...) {
+  effectnames = NA
   if (class(fit)[1] == "lmerModLmerTest") {
     test = "Pr(>F)"
     anovafit = suppressMessages(anova(fit, type = type, ... ))
@@ -28,6 +29,9 @@ effectpowermc = function(fit, type="III", test = "Pr(>Chisq)", ...) {
       effect_pvals = rep(NA,length(effectnames))
     })
   }
+  if (all(is.na(effectnames))) {
+    stop("Effect power not supported for fit type: ", class(fit))
+  }
   if ("Residuals" %in% effectnames) {
     effect_pvals = effect_pvals[-length(effect_pvals)]
     names(effect_pvals) = effectnames[-length(effectnames)]
